From 823454f1ea140ec47f5f9c5c3c5ad62eb458eb8a Mon Sep 17 00:00:00 2001
From: Gilles Dartiguelongue <eva@gentoo.org>
Date: Wed, 24 Oct 2018 10:52:46 +0200
Subject: [PATCH 2/5] Add support for gentoo in cloud.cfg and templates

---
 config/cloud.cfg.tmpl       |  8 ++++++--
 templates/hosts.gentoo.tmpl | 24 ++++++++++++++++++++++++
 tools/render-cloudcfg       |  2 +-
 3 files changed, 31 insertions(+), 3 deletions(-)
 create mode 100644 templates/hosts.gentoo.tmpl

diff --git a/config/cloud.cfg.tmpl b/config/cloud.cfg.tmpl
index 1fef133a..3f5a41a2 100644
--- a/config/cloud.cfg.tmpl	2020-12-27 18:35:39.107000000 +0000
+++ b/config/cloud.cfg.tmpl	2020-12-27 18:38:23.982000000 +0000
@@ -154,7 +154,7 @@ cloud_final_modules:
 system_info:
    # This will affect which distro class gets used
 {% if variant in ["alpine", "amazon", "arch", "centos", "debian",
-                  "fedora", "freebsd", "netbsd", "openbsd", "rhel",
+                  "fedora", "freebsd", "gentoo", "netbsd", "openbsd", "rhel",
                   "suse", "ubuntu"] %}
    distro: {{ variant }}
 {% else %}
@@ -206,7 +206,7 @@ system_info:
          primary: http://ports.ubuntu.com/ubuntu-ports
          security: http://ports.ubuntu.com/ubuntu-ports
    ssh_svcname: ssh
-{% elif variant in ["alpine", "amazon", "arch", "centos", "fedora",
+{% elif variant in ["alpine", "amazon", "arch", "centos", "fedora", "gentoo",
                     "rhel", "suse"] %}
    # Default user name + that default users groups (if added/used)
    default_user:
@@ -221,6 +221,10 @@ system_info:
 {% endif %}
 {% if variant == "suse" %}
      groups: [cdrom, users]
+{% elif variant == "gentoo" %}
+     groups: [users, wheel]
+     primary_group: users
+     no_user_group: true
 {% elif variant == "alpine" %}
      groups: [adm, sudo]
 {% elif variant == "arch" %}
diff --git a/templates/hosts.gentoo.tmpl b/templates/hosts.gentoo.tmpl
new file mode 100644
index 00000000..cd045fa6
--- /dev/null
+++ b/templates/hosts.gentoo.tmpl
@@ -0,0 +1,24 @@
+## template:jinja
+{#
+This file /etc/cloud/templates/hosts.gentoo.tmpl is only utilized
+if enabled in cloud-config.  Specifically, in order to enable it
+you need to add the following to config:
+  manage_etc_hosts: True
+-#}
+# Your system has configured 'manage_etc_hosts' as True.
+# As a result, if you wish for changes to this file to persist
+# then you will need to either
+# a.) make changes to the master file in /etc/cloud/templates/hosts.gentoo.tmpl
+# b.) change or remove the value of 'manage_etc_hosts' in
+#     /etc/cloud/cloud.cfg or cloud-config from user-data
+# 
+# The following lines are desirable for IPv4 capable hosts
+127.0.0.1 {{fqdn}} {{hostname}}
+127.0.0.1 localhost.localdomain localhost
+127.0.0.1 localhost4.localdomain4 localhost4
+
+# The following lines are desirable for IPv6 capable hosts
+::1 {{fqdn}} {{hostname}}
+::1 localhost.localdomain localhost
+::1 localhost6.localdomain6 localhost6
+
diff --git a/tools/render-cloudcfg b/tools/render-cloudcfg
index 8b7cb875..d109044e 100755
--- a/tools/render-cloudcfg     2020-12-27 18:44:22.032049636 +0000
+++ a/tools/render-cloudcfg     2020-12-27 18:44:41.632619051 +0000
@@ -5,7 +5,7 @@ import os
 import sys
 
 VARIANTS = ["alpine", "amazon", "arch", "centos", "debian", "fedora",
-            "freebsd", "netbsd", "openbsd", "rhel", "suse", "ubuntu",
+            "freebsd", "gentoo", "netbsd", "openbsd", "rhel", "suse", "ubuntu",
             "unknown"]
